flight\_arbitrage package
=========================

.. automodule:: flight_arbitrage
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::
   :maxdepth: 4

   flight_arbitrage.flight
   flight_arbitrage.hidden_city
